# JXAutoML

A package that provides smart tuning using greedy algorithms, and also enables feature selection as part of hyperparameter tuning.


`from JXAutoML.JiaoCheng import JiaoCheng`: Ultra Greedy Tuner Advanced

`from JXAutoML.JiaoChengB import JiaoChengB`: Ultra Greedy Tuner Advanced 

`from JXAutoML.YangZhouB import YangZhouB`: Greedy Tuner

`from JXAutoML.NingXiang import NingXiang`: Feature Selection tool with RandomForest or XGBoost